Class: Aws::ForecastQueryService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ForecastQueryService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-forecastqueryservice/client.rb,
sig/client.rbs
Overview
An API client for ForecastQueryService. To construct a client, you need to configure a :region and :credentials.
client = Aws::ForecastQueryService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _QueryForecastResponseSuccess, _QueryWhatIfForecastResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#query_forecast(params = {}) ⇒ Types::QueryForecastResponse
Retrieves a forecast for a single item, filtered by the supplied criteria.
-
#query_what_if_forecast(params = {}) ⇒ Types::QueryWhatIfForecastResponse
Retrieves a what-if forecast.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
668 669 670 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 668 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
671 672 673 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 671 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 641 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ForecastQueryService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-forecastqueryservice' context[:gem_version] = '1.71.0' Seahorse::Client::Request.new(handlers, context) end |
#query_forecast(params = {}) ⇒ Types::QueryForecastResponse
Retrieves a forecast for a single item, filtered by the supplied criteria.
The criteria is a key-value pair. The key is either item_id (or the
equivalent non-timestamp, non-target field) from the
TARGET_TIME_SERIES dataset, or one of the forecast dimensions
specified as part of the FeaturizationConfig object.
By default, QueryForecast returns the complete date range for the
filtered forecast. You can request a specific date range.
To get the full forecast, use the CreateForecastExportJob operation.
87 |
# File 'sig/client.rbs', line 87
def query_forecast: (
|
#query_what_if_forecast(params = {}) ⇒ Types::QueryWhatIfForecastResponse
Retrieves a what-if forecast.
101 |
# File 'sig/client.rbs', line 101
def query_what_if_forecast: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
661 662 663 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 661 def waiter_names [] end |