Class: Aws::ForecastQueryService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ForecastQueryService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-forecastqueryservice/client.rb
Overview
An API client for ForecastQueryService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ForecastQueryService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#query_forecast(params = {}) ⇒ Types::QueryForecastResponse
Retrieves a forecast for a single item, filtered by the supplied criteria.
-
#query_what_if_forecast(params = {}) ⇒ Types::QueryWhatIfForecastResponse
Retrieves a what-if forecast.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
423 424 425 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 423 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
608 609 610 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 608 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
611 612 613 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 611 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 586 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-forecastqueryservice' context[:gem_version] = '1.38.0' Seahorse::Client::Request.new(handlers, context) end |
#query_forecast(params = {}) ⇒ Types::QueryForecastResponse
Retrieves a forecast for a single item, filtered by the supplied criteria.
The criteria is a key-value pair. The key is either ‘item_id` (or the equivalent non-timestamp, non-target field) from the `TARGET_TIME_SERIES` dataset, or one of the forecast dimensions specified as part of the `FeaturizationConfig` object.
By default, ‘QueryForecast` returns the complete date range for the filtered forecast. You can request a specific date range.
To get the full forecast, use the [CreateForecastExportJob] operation.
<note markdown=“1”> The forecasts generated by Amazon Forecast are in the same timezone as the dataset that was used to create the predictor.
</note>
[1]: docs.aws.amazon.com/en_us/forecast/latest/dg/API_CreateForecastExportJob.html
511 512 513 514 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 511 def query_forecast(params = {}, = {}) req = build_request(:query_forecast, params) req.send_request() end |
#query_what_if_forecast(params = {}) ⇒ Types::QueryWhatIfForecastResponse
Retrieves a what-if forecast.
577 578 579 580 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 577 def query_what_if_forecast(params = {}, = {}) req = build_request(:query_what_if_forecast, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
601 602 603 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 601 def waiter_names [] end |