Class: Aws::ForecastQueryService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ForecastQueryService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-forecastqueryservice/client.rb
Overview
An API client for ForecastQueryService. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::ForecastQueryService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#query_forecast(params = {}) ⇒ Types::QueryForecastResponse
Retrieves a forecast for a single item, filtered by the supplied criteria.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
356 357 358 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 356 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
475 476 477 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 475 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
478 479 480 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 478 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 453 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-forecastqueryservice' context[:gem_version] = '1.20.0' Seahorse::Client::Request.new(handlers, context) end |
#query_forecast(params = {}) ⇒ Types::QueryForecastResponse
Retrieves a forecast for a single item, filtered by the supplied criteria.
The criteria is a key-value pair. The key is either `item_id` (or the equivalent non-timestamp, non-target field) from the `TARGET_TIME_SERIES` dataset, or one of the forecast dimensions specified as part of the `FeaturizationConfig` object.
By default, `QueryForecast` returns the complete date range for the filtered forecast. You can request a specific date range.
To get the full forecast, use the [CreateForecastExportJob] operation.
<note markdown=“1”> The forecasts generated by Amazon Forecast are in the same timezone as the dataset that was used to create the predictor.
</note>
[1]: docs.aws.amazon.com/en_us/forecast/latest/dg/API_CreateForecastExportJob.html
444 445 446 447 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 444 def query_forecast(params = {}, = {}) req = build_request(:query_forecast, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
468 469 470 |
# File 'lib/aws-sdk-forecastqueryservice/client.rb', line 468 def waiter_names [] end |